// VRAMCopy.h
//
// Fast copy routines for copying data to/from VRAM (without DMA).
//
// @author Hans de Ruiter
//
// @copyright (C) 2010 by Hans de Ruiter, all rights reserved
//
// @version 0.1 - 2010/09/20

#ifndef __VRAMCOPY_H__
#define __VRAMCOPY_H__

/** Copies a block of memory from main memory to VRAM using the optimal method (e.g., altivec).
 *
 * @param src pointer to the source buffer in main memory
 * @param dest pointer to the destination buffer in VRAM
 * @param numBytes the number of bytes to copy
 */
void copyToVRAM(const void *src, void *dest, unsigned int numBytes);

/** Copies a block of memory from VRAM to main memory using the optimal method (e.g., altivec).
 *
 * @param src pointer to the source buffer in VRAM
 * @param dest pointer to the destination buffer in main memory
 * @param numBytes the number of bytes to copy
 */
void copyFromVRAM(const void *src, void *dest, unsigned int numBytes);

/** Copies a block of memory from main memory to VRAM without using altivec.
 *
 * @param src pointer to the source buffer in main memory
 * @param dest pointer to the destination buffer in VRAM
 * @param numBytes the number of bytes to copy
 */
void copyToVRAMNoAltivec(const void *src, void *dest, unsigned int numBytes);

/** Copies a block of memory from VRAM to main memory without using altivec.
 *
 * @param src pointer to the source buffer in VRAM
 * @param dest pointer to the destination buffer in main memory
 * @param numBytes the number of bytes to copy
 */
void copyFromVRAMNoAltivec(const void *src, void *dest, unsigned int numBytes);

/** Copies a block of memory from main memory to VRAM using altivec.
 *
 * @param src pointer to the source buffer in main memory
 * @param dest pointer to the destination buffer in VRAM
 * @param numBytes the number of bytes to copy
 */
void copyToVRAMAltivec(const void *src, void *dest, unsigned int numBytes);

/** Copies a block of memory from VRAM to main memory using altivec.
 *
 * @param src pointer to the source buffer in VRAM
 * @param dest pointer to the destination buffer in main memory
 * @param numBytes the number of bytes to copy
 */
void copyFromVRAMAltivec(const void *src, void *dest, unsigned int numBytes);

#endif
